@@ -4,7 +4,7 @@ from azure.storage.blob import BlobClient
 
 class PyblobLogger:
 
-    DEBUG_LEVEL = logging.DEBUG
+    DEBUG_LEVEL = logging.WARNING
     ERROR_LEVEL = logging.ERROR
     LOGGING_FORMAT = '%(asctime)s - %(name)s - %(message)s'
     DIRECTORY_NAME_LENGTH = 5
@@ -28,13 +28,6 @@ class PyblobLogger:
     def setup_debug_logger(self, logger_name):
         self.debug_logger = logging.getLogger('DEBUG - ' + logger_name)
         self.debug_logger.setLevel(self.DEBUG_LEVEL)
-
-        logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.authentication.cbs_auth").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.connection").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.receiver").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.*").setLevel(logging.WARNING)
-        logging.getLogger("uamqp").setLevel(logging.WARNING)
 	 
         file_handler = logging.FileHandler(self.get_debug_logs_name())
         file_handler.setLevel(self.DEBUG_LEVEL)
@@ -53,13 +46,6 @@ class PyblobLogger:
         self.error_logger = logging.getLogger('ERROR - ' + logger_name)
         self.error_logger.setLevel(self.ERROR_LEVEL)
 
-        logging.getLogger("azure.core.pipeline.policies.http_logging_policy").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.authentication.cbs_auth").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.connection").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.receiver").setLevel(logging.WARNING)
-        logging.getLogger("uamqp.*").setLevel(logging.WARNING)
-        logging.getLogger("uamqp").setLevel(logging.WARNING)
-
         file_handler = logging.FileHandler(self.get_error_logs_name())
         file_handler.setLevel(self.ERROR_LEVEL)
 
